@@ -6,7 +6,8 @@
 #' @param object [\code{Network}]\cr
 #'   Network.
 #' @param path [\code{integer}]\cr
-#'   An integer vector containing the order of cities of a path. Keep in mind,
+#'   An integer vector containing the order of cities of a path or a list
+#'   of multiple paths. Keep in mind
 #'   that instances with \eqn{n} nodes and \eqn{m} depots have \eqn{n + m}
 #'   coordinates, with the \eqn{1,\ldots,m} first coordinates belonging to
 #'   the depots.
@@ -15,6 +16,11 @@
 #'   closed to a cycle. Default is \code{FALSE}.
 #' @param path.colour [\code{character(1)}]\cr
 #'   Colour of the lines linking nodes on a path. Default is \dQuote{gray}.
+#' @param use.opt.tour [\code{logical(1)}]\cr
+#'   If the given network knows its optimal tour, should it be plotted?
+#'   If this is the case and \code{path} is given additionally, the optimal
+#'   tour is ignored.
+#'   Default is \code{FALSE}.
 #' @param ... [any]\cr
 #'   Currently not used.
 #' @return [\code{\link[ggplot2]{ggplot}}]
@@ -30,7 +36,16 @@
 #' @export
 autoplot.Network = function(object,
   path = NULL, close.path = FALSE, path.colour = "gray",
+  use.opt.tour = FALSE,
   ...) {
+  if (!is.null(path)) {
+    if (!testNumeric(path, min.len = 2L, any.missing = FALSE) & !testList(path, min.len = 2L, any.missing = FALSE)) {
+      stopf("Path argument needs to be a vector or a list.")
+    }
+  }
+  assertString(path.colour, na.ok = FALSE)
+  assertFlag(close.path, na.ok = FALSE)
+
   if (ncol(object$coordinates) > 2L) {
     stopf("Only 2-dimensional networks can be plotted.")
   }
@@ -46,23 +61,51 @@ autoplot.Network = function(object,
     df.depots = df[depot.idx, , drop = FALSE]
   }
 
+  if (is.list(path)) {
+    n = nrow(df)
+    df = df[rep(seq_len(n), length(path)), ]
+    ns = if (!is.null(names(path))) names(path) else as.character(seq_len(length(path)))
+    df$Path = rep(ns, each = n)
+  }
+
   pl = ggplot(data = df, mapping = aes_string(x = "x1", y = "x2"))
 
-  if (!is.null(path)) {
-    assertInteger(path, min.len = 2L, any.missing = FALSE)
-    assertCharacter(path.colour, len = 1L, any.missing = FALSE)
-    assertFlag(close.path)
-    if (close.path) {
-      path = c(path, path[1])
+  # facets if multiple paths given
+  if (is.list(path)) {
+    pl = pl + facet_grid(. ~ Path)
+  }
+
+  if (!is.null(path) || !is.null(use.opt.tour)) {
+    # if we have a list of pathes
+    if (is.list(path)) {
+      # sequentially build pathes (one path per facet)
+      path.coords = data.frame()
+      for (i in seq_len(length(path))) {
+        p = path[[i]]
+        pname = names(path)[i]
+        if (close.path) {
+          p = c(p, p[1])
+        }
+        the.path.coords = df[p, , drop = FALSE]
+        the.path.coords$Path = pname
+        path.coords = rbind(path.coords, the.path.coords)
+      }
+    } else {
+      # do the same as above only for one path
+      path = if (use.opt.tour) object$opt.tour else path
+      close.path = if (use.opt.tour) TRUE else close.path
+      if (close.path) {
+        path = c(path, path[1])
+      }
+      path.coords = df[path, , drop = FALSE]
     }
-    path.coords = df[path, , drop = FALSE]
     pl = pl + geom_path(data = path.coords, colour = path.colour)
   }
 
   if (!is.null(df$membership)) {
     pl = pl + geom_point(aes_string(colour = "membership"))
   } else {
-    pl = pl + geom_point(colour = "tomato")
+    pl = pl + geom_point(colour = "black")
   }
 
   if (hasDepots(object)) {
