@@ -1,9 +1,9 @@
 #' Check if network has depots.
 #'
-#' @param x [\code{Network}]\cr
-#'   Network.
+#' @template arg_network
 #' @return [\code{logical(1)}]
 #' @export
 hasDepots = function(x) {
-    !is.null(x$depot.coordinates)
+  assertClass(x, "Network")
+  !is.null(x$depot.coordinates)
 }
